diff pkg/imports/fm_bcnlat.go @ 4911:bcb8b69e4358 fairway-marks-import

Type specific names for fairway marks import
author Tom Gottfried <tom@intevation.de>
date Mon, 10 Feb 2020 18:02:22 +0100
parents 6f244b5eb716
children bfd8ef836998
line wrap: on
line diff
--- a/pkg/imports/fm_bcnlat.go	Mon Feb 10 17:07:18 2020 +0100
+++ b/pkg/imports/fm_bcnlat.go	Mon Feb 10 18:02:22 2020 +0100
@@ -34,13 +34,13 @@
 	return bcnlat.URL + "|" + bcnlat.FeatureType, nil
 }
 
-// FMJobKind is the import queue type identifier.
-const FMJobKind JobKind = "fm"
+// BCNLATJobKind is the import queue type identifier.
+const BCNLATJobKind JobKind = "fm_bcnlat"
 
 type bcnlatJobCreator struct{}
 
 func init() {
-	RegisterJobCreator(FMJobKind, bcnlatJobCreator{})
+	RegisterJobCreator(BCNLATJobKind, bcnlatJobCreator{})
 }
 
 func (bcnlatJobCreator) Description() string { return "fairway marks bcnlat" }